@@ -13,9 +13,21 @@
 
 #include <Transaction/AddonList.h>
 
+#ifdef DISCOVER_USE_STABLE_APPSTREAM
+#include <AppStreamQt5/developer.h>
+#include <AppStreamQt5/icon.h>
+#include <AppStreamQt5/release.h>
+#include <AppStreamQt5/screenshot.h>
+#include <AppStreamQt5/utils.h>
+#include <AppStreamQt5/version.h>
+#else
 #include <AppStreamQt/icon.h>
+#include <AppStreamQt/release.h>
 #include <AppStreamQt/screenshot.h>
 #include <AppStreamQt/utils.h>
+#include <AppStreamQt/version.h>
+#endif
+
 #include <appstream/AppStreamUtils.h>
 
 #include <KConfigGroup>
@@ -24,7 +36,6 @@
 #include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
 
-#include <AppStreamQt/release.h>
 #include <QDebug>
 #include <QDesktopServices>
 #include <QDir>
@@ -113,9 +124,19 @@ QList<PackageState> FlatpakResource::addonsInformation()
 QString FlatpakResource::availableVersion() const
 {
     if (m_availableVersion.isEmpty()) {
+#if ASQ_CHECK_VERSION(1, 0, 0)
+        const auto releases = m_appdata.releasesPlain().entries();
+#else
         const auto releases = m_appdata.releases();
+#endif
         if (!releases.isEmpty()) {
-            m_availableVersion = releases.constFirst().version();
+            auto latestVersion = releases.constFirst().version();
+            for (const auto &release : releases) {
+                if (AppStream::Utils::vercmpSimple(release.version(), latestVersion) > 0) {
+                    latestVersion = release.version();
+                }
+            };
+            m_availableVersion = latestVersion;
             return m_availableVersion;
         }
     } else {
@@ -643,8 +664,13 @@ QUrl FlatpakResource::url() const
 
 QDate FlatpakResource::releaseDate() const
 {
-    if (!m_appdata.releases().isEmpty()) {
-        auto release = m_appdata.releases().constFirst();
+#if ASQ_CHECK_VERSION(1, 0, 0)
+    if (const auto optional = m_appdata.releasesPlain().indexSafe(0); optional.has_value()) {
+        auto release = optional.value();
+#else
+    if (const auto releases = m_appdata.releases(); !releases.isEmpty()) {
+        auto release = releases.constFirst();
+#endif
         return release.timestamp().date();
     }
 
@@ -667,7 +693,11 @@ QString FlatpakResource::sourceIcon() const
 
 QString FlatpakResource::author() const
 {
+#if ASQ_CHECK_VERSION(1, 0, 0)
+    QString name = m_appdata.developer().name();
+#else
     QString name = m_appdata.developerName();
+#endif
 
     if (name.isEmpty()) {
         name = m_appdata.projectGroup();
@@ -705,8 +735,13 @@ QString FlatpakResource::versionString()
         if (ref) {
             version = flatpak_installed_ref_get_appdata_version(ref);
         }
+#if ASQ_CHECK_VERSION(1, 0, 0)
+    } else if (!m_appdata.releasesPlain().isEmpty()) {
+        const auto release = m_appdata.releasesPlain().indexSafe(0).value();
+#else
     } else if (!m_appdata.releases().isEmpty()) {
-        auto release = m_appdata.releases().constFirst();
+        const auto release = m_appdata.releases().constFirst();
+#endif
         version = release.version();
     } else {
         version = m_id.branch;
